@@ -176,6 +176,10 @@ cLib.ionic_agent_set_metadata.argtypes = [OWNED_POINTER(CAgent), c_char_p, c_cha
 cLib.ionic_agent_set_metadata.restype = c_int
 cLib.ionic_agent_set_metadata.errcheck = ctypesFunctionErrorCheck
 
+cLib.ionic_agent_add_metadata.argtypes = [OWNED_POINTER(CAgent), OWNED_POINTER(CMetadataMap)]
+cLib.ionic_agent_add_metadata.restype = c_int
+cLib.ionic_agent_add_metadata.errcheck = ctypesFunctionErrorCheck
+
 cLib.ionic_agent_rmv_metadata.argtypes = [OWNED_POINTER(CAgent), c_char_p]
 cLib.ionic_agent_rmv_metadata.restype = c_int
 cLib.ionic_agent_rmv_metadata.errcheck = ctypesFunctionErrorCheck
@@ -186,11 +190,20 @@ cLib.ionic_agent_get_metadata.restype = OWNED_POINTER(c_char)
 cLib.ionic_agent_get_metadata_keys_array.argtypes = [OWNED_POINTER(CAgent), POINTER(c_size_t)]
 cLib.ionic_agent_get_metadata_keys_array.restype = OWNED_POINTER(c_char)
 
+cLib.ionic_metadata_collector_process_environment.argtypes = [POINTER(c_char_p), c_size_t]
+cLib.ionic_metadata_collector_process_environment.restype = OWNED_POINTER(CMetadataMap)
+
+cLib.ionic_metadata_collector_network.argtypes = []
+cLib.ionic_metadata_collector_network.restype = OWNED_POINTER(CMetadataMap)
+
 IONIC_AGENT_META_CLIENT_TYPE = CMarshalUtil.stringFromC((c_char_p).in_dll(cLib, 'IONIC_AGENT_META_CLIENT_TYPE').value)
 IONIC_AGENT_META_CLIENT_VERSION = CMarshalUtil.stringFromC((c_char_p).in_dll(cLib, 'IONIC_AGENT_META_CLIENT_VERSION').value)
 IONIC_AGENT_META_APPLICATION_NAME = CMarshalUtil.stringFromC((c_char_p).in_dll(cLib, 'IONIC_AGENT_META_APPLICATION_NAME').value)
 IONIC_AGENT_META_APPLICATION_VERSION = CMarshalUtil.stringFromC((c_char_p).in_dll(cLib, 'IONIC_AGENT_META_APPLICATION_VERSION').value)
 IONIC_AGENT_META_SAVED_FROM = CMarshalUtil.stringFromC((c_char_p).in_dll(cLib, 'IONIC_AGENT_META_SAVED_FROM').value)
+IONIC_AGENT_META_HOSTNAME = CMarshalUtil.stringFromC((c_char_p).in_dll(cLib, 'IONIC_AGENT_META_HOSTNAME').value)
+IONIC_AGENT_META_MAC_ADDRS = CMarshalUtil.stringFromC((c_char_p).in_dll(cLib, 'IONIC_AGENT_META_MAC_ADDRS').value)
+IONIC_AGENT_META_IFACE_ADDRS = CMarshalUtil.stringFromC((c_char_p).in_dll(cLib, 'IONIC_AGENT_META_IFACE_ADDRS').value)
 
 cLib.ionic_create_keydata_array.argtypes = [c_size_t,]
 cLib.ionic_create_keydata_array.restype = OWNED_POINTER(CKeyDataArray)
@@ -302,10 +315,14 @@ cLib.ionic_agent_create_id_assertion.argtypes = [OWNED_POINTER(CAgent), c_char_p
 cLib.ionic_agent_create_id_assertion.restype = c_int
 cLib.ionic_agent_create_id_assertion.errcheck = ctypesFunctionErrorCheck
 
-cLib.ionic_agent_validate_assertion.argtypes = [OWNED_POINTER(CAgent), c_char_p, c_char_p, c_char_p, c_char_p]
+cLib.ionic_agent_validate_assertion.argtypes = [OWNED_POINTER(CAgent), c_char_p, c_char_p, c_char_p, c_char_p, c_char_p]
 cLib.ionic_agent_validate_assertion.restype = c_int
 cLib.ionic_agent_validate_assertion.errcheck = ctypesFunctionErrorCheck
 
+cLib.ionic_agent_validate_assertion_via_enrollment.argtypes = [OWNED_POINTER(CAgent), c_char_p, c_char_p, c_char_p, c_char_p]
+cLib.ionic_agent_validate_assertion_via_enrollment.restype = c_int
+cLib.ionic_agent_validate_assertion_via_enrollment.errcheck = ctypesFunctionErrorCheck
+
 cLib.ionic_agent_get_resource.argtypes = [OWNED_POINTER(CAgent), POINTER(CResourceRequest), OWNED_POINTER(CMetadataMap), POINTER(POINTER(CResourceResponse)), POINTER(POINTER(CServerResponse))]
 cLib.ionic_agent_get_resource.restype = c_int
 cLib.ionic_agent_get_resource.errcheck = ctypesFunctionErrorCheck
