@@ -285,6 +285,17 @@ cLib.ionic_profile_persistor_create_aesgcm_file.restype = OWNED_POINTER(CProfile
 cLib.ionic_profile_persistor_create_plaintext_file.argtypes = [c_char_p]
 cLib.ionic_profile_persistor_create_plaintext_file.restype = OWNED_POINTER(CProfilePersistor)
 
+if os.name == 'posix':
+    if sys.platform == 'mac' or sys.platform == 'darwin':
+        cLib.ionic_profile_persistor_create_mac.argtypes = [c_char_p, c_char_p]
+        cLib.ionic_profile_persistor_create_mac.restype = OWNED_POINTER(CProfilePersistor)
+    else:
+        cLib.ionic_profile_persistor_create_linux.argtypes = [c_char_p]
+        cLib.ionic_profile_persistor_create_linux.restype = OWNED_POINTER(CProfilePersistor)
+else:
+    cLib.ionic_profile_persistor_create_windows.argtypes = [c_char_p]
+    cLib.ionic_profile_persistor_create_windows.restype = OWNED_POINTER(CProfilePersistor)
+
 cLib.ionic_profile_persistor_get_version.argtypes = [POINTER(CProfilePersistor)]
 cLib.ionic_profile_persistor_get_version.restype = OWNED_POINTER(c_char)
 
