@@ -155,10 +155,28 @@ class CreateKeysRequest(object):
     """!Class used to request multiple keys with varying attributes."""
     class KeyRequest(object):
         """!Inner class for CreateKeyRequest to hold groups of counts and attributes"""
+
         def __init__(self, ref, count, attributes, mutableattributes = None):
+            """!Constructor
+
+            @param
+                ref (String) A string value that will be included with the created 
+                    keys that can be used to match them with the provided attributes
+            @param
+                count (int) The number of keys with the given attributes to be created
+            @param
+                attributes (KeyAttributesDict) The attributes to be set for these keys
+            @param
+                mutableattributes (KeyAttributesDict) The mutable attributes to be set
+                    for these keys
+            """
+            ## ref (String) A string value that will be included with the created keys that can be used to match them with the provided attributes
             self.ref = ref
+            ## count (int) The number of keys with the given attributes to be created
             self.count = count
+            ## attributes (KeyAttributesDict) The attributes to be set for these keys
             self.attributes = attributes
+            ## mutableattributes (KeyAttributesDict) The mutable attributes to be set for these keys
             self.mutableattributes = mutableattributes
     def __init__(self, metadata = None, simulate = False):
         """!Constructor for CreateKeyRequest.
@@ -171,8 +189,12 @@ class CreateKeysRequest(object):
                 contain keys that are allowed to be created with empty ID and
                 key byte values.
         """
+
+        ##(dict) metadata associated with the request
         self.metadata = metadata
+        ##(bool) whether to check if the key is retrievable, or actually retrieve it.
         self.simulate = simulate
+        ##(list) list of keys to request
         self.keys = []
 
     def addkeyrequest(self, ref, count, attributes, mutableattributes = None):
@@ -188,6 +210,8 @@ class CreateKeysRequest(object):
         @param
             mutableattributes (KeyAttributesDict) The mutable attributes to be set
                 for these keys
+        @return
+            None
         """
         self.keys.append(self.KeyRequest(ref, count, attributes, mutableattributes))
 
@@ -695,6 +719,19 @@ class Agent(AgentKeyServicesBase):
         cMeta = MetadataDict._marshalToC(metadatadict)
         _private.cLib.ionic_agent_set_metadata_all(self._cAgent, cMeta)
 
+    def addmetadata(self, metadatadict):
+        """!Add metadata dictionary to any meta data already on the agent.
+        A metadata key passed in here with an empty value is removed from the agent.
+
+        @param
+            metadatadict (MetadataDict, optional): The metadata properties to send
+                along with the HTTP request.
+        @return
+            None, raises an exception on errors
+        """
+        cMeta = MetadataDict._marshalToC(metadatadict)
+        _private.cLib.ionic_agent_add_metadata(self._cAgent, cMeta)
+
     # profile persistence
     def loadprofiles(self, persistor):
         """!(DEPRECATED) Load device profiles using the provided profile persistor.
@@ -1280,7 +1317,7 @@ class Agent(AgentKeyServicesBase):
         # marshal C output to Python
         return _private.CMarshalUtil.stringFromC(cAssertion)
 
-    def validateassertion(self, keyspace, assertionBase64, foruri = None, nonce = None):
+    def validateassertion(self, keyspace, assertionBase64, foruri = None, nonce = None, knsurl = None):
         """!Given a base 64 encoded Ionic assertion, validate it against the keyspace public key.
             This method makes an HTTP call to Ionic.com to get keyspace information including the public key.
             It checks the assertion formating, checks the valid time window, and finally checks the RSA
@@ -1299,7 +1336,9 @@ class Agent(AgentKeyServicesBase):
             It should match the one passed when creating the assertion.
             If this option is left off, the validation uses a default value.
             If this value is incorrect, validation will fail.
-                                    
+        @param
+           knsurl (string): An optional alternate kns provider url, defaults to https://api.ionic.com
+
         @return
             None, function will throw an exception if it fails to validate.
         """
@@ -1308,8 +1347,40 @@ class Agent(AgentKeyServicesBase):
         cAssertionBase64 = _private.CMarshalUtil.stringToC(assertionBase64)
         cForUri = _private.CMarshalUtil.stringToC(foruri)
         cNonce = _private.CMarshalUtil.stringToC(nonce)
+        cknsurl = _private.CMarshalUtil.stringToC(knsurl)
 
-        _private.cLib.ionic_agent_validate_assertion(self._cAgent, cKeyspace, cAssertionBase64, cForUri, cNonce)
+        _private.cLib.ionic_agent_validate_assertion(self._cAgent, cKeyspace, cAssertionBase64, cForUri, cNonce, cknsurl)
+
+    def validateAssertionViaEnrollment(self, enrollmentUrl, assertionBase64, foruri = None, nonce = None):
+        """!Given a base 64 encoded Ionic assertion, validate it against the keyspace public key.
+            This method makes an HTTP call to your enrollment server to get the public key.
+            It checks the assertion formatting, checks the valid time window, and finally checks the RSA
+            signature against the public key for the keyspace.
+
+        @param
+            enrollmentUrl (string): The enrollment URL for the given keyspace.
+        @param
+            assertionBase64 (string): The Ionic formatted base 64 encoded assertion.
+        @param
+            foruri (string): An optional recipient string. 
+            It should match the one passed when creating the assertion.
+            If this option is left off, recipient checks are skipped.
+        @param
+            nonce (string): An optional nonce string. 
+            It should match the one passed when creating the assertion.
+            If this option is left off, the validation uses a default value.
+            If this value is incorrect, validation will fail.
+
+        @return
+            None, function will throw an exception if it fails to validate.
+        """
+
+        cEnrollmentUrl = _private.CMarshalUtil.stringToC(enrollmentUrl)
+        cAssertionBase64 = _private.CMarshalUtil.stringToC(assertionBase64)
+        cForUri = _private.CMarshalUtil.stringToC(foruri)
+        cNonce = _private.CMarshalUtil.stringToC(nonce)
+
+        _private.cLib.ionic_agent_validate_assertion_via_enrollment(self._cAgent, cEnrollmentUrl, cAssertionBase64, cForUri, cNonce)
 
     def getresource(self, resourceid, args = None, metadata = None):
         """!Gets a generic resource from Ionic.com.
@@ -1427,3 +1498,50 @@ class Agent(AgentKeyServicesBase):
                                             
         # marshal C output to Python
         return KeyspaceResponse._marshalFromC(cResponse.contents)
+
+
+class AgentMetadataCollectorNetwork(object):
+    """!Class used to generate a metadata object containing network identifiers."""
+
+    ##(string) The "hostname" key
+    IONIC_AGENT_META_HOSTNAME = _private.IONIC_AGENT_META_HOSTNAME
+    ##(string) The "mac_addrs" key
+    IONIC_AGENT_META_MAC_ADDRS = _private.IONIC_AGENT_META_MAC_ADDRS
+    ##(string) The "iface_addrs" key
+    IONIC_AGENT_META_IFACE_ADDRS = _private.IONIC_AGENT_META_IFACE_ADDRS
+
+
+    def getmetadata(self):
+        """!Get the metadata map.
+
+        @return  
+            Returns a MetadataMap containing data related to network interfaces.
+        """
+        cMetadata = _private.cLib.ionic_metadata_collector_network()
+        return MetadataDict._marshalFromC(cMetadata)
+
+
+class AgentMetadataCollectorProcessEnvironment(object):
+    """!Class used to generate a metadata object containing environment variables."""
+    def __init__(self, listOfEnvironmentKeys):
+        """!Constructor
+
+        @param
+        listOfEnvironmentKeys (list of string): environment variables to fetch
+
+        """
+
+        ##(list of strings) The list of environment variables to fetch
+        self.listOfKeys = listOfEnvironmentKeys
+
+    def getmetadata(self):
+        """!Get the metadata map.
+
+        @return  
+            Returns a MetadataMap containing environment data.
+        """
+        nKeyCount = len(self.listOfKeys)
+        cKeyArray = _private.CMarshalUtil.stringArrayToC(self.listOfKeys)
+
+        cMetadata = _private.cLib.ionic_metadata_collector_process_environment(cKeyArray, nKeyCount)
+        return MetadataDict._marshalFromC(cMetadata)
