@@ -44,11 +44,11 @@ class ChunkCipherEncryptAttributes(object):
         """!Constructor for decrypt attributes, can pass in attributes, and then assign any other member variables.
             
         @param
-            attributes (agent::KeyAttributesDict) The key attributes to associate with data chunk protection key
+            attributes (KeyAttributesDict) The key attributes to associate with data chunk protection key
         @param
-            metadata (agent::MetadataDict) The metadata properties to send along with the HTTP request
+            metadata (MetadataDict) The metadata properties to send along with the HTTP request
         @param
-            mutableAttributes (agent::KeyAttributesDict) The key mutable attributes to associate with data chunk protection key
+            mutableAttributes (KeyAttributesDict) The key mutable attributes to associate with data chunk protection key
         """
 
         ##(string) The key ID (also known as the key tag)
@@ -57,11 +57,11 @@ class ChunkCipherEncryptAttributes(object):
         self.keydataOut = None
         ##(string) The data chunk cipher ID that the data was encrypted with
         self.cipheridOut = None
-        ##(agent::KeyAttributesDict) The key attributes to associate with data chunk protection key
+        ##(\link ionicsdk.common.KeyAttributesDict KeyAttributesDict \endlink) The key attributes to associate with data chunk protection key
         self.attributes = attributes
-        ##(agent::KeyAttributesDict) The key mutable attributes to associate with data chunk protection key
+        ##(\link ionicsdk.common.KeyAttributesDict KeyAttributesDict \endlink) The key mutable attributes to associate with data chunk protection key
         self.mutableAttributes = mutableAttributes
-        ##(agent::MetadataDict) The metadata properties to send along with the HTTP request
+        ##(\link ionicsdk.common.MetadataDict MetadataDict \endlink) The metadata properties to send along with the HTTP request
         self.metadata = metadata
 
 class ChunkCipherDecryptAttributes(object):
@@ -71,7 +71,7 @@ class ChunkCipherDecryptAttributes(object):
         """!Constructor for decrypt attributes, can pass in metadata, and then assign any other member variables.
             
         @param
-            metadata (agent::MetadataDict) The metadata properties to send along with the HTTP request
+            metadata (MetadataDict) The metadata properties to send along with the HTTP request
         """
 
         ##(string) The key ID (also known as the key tag)
@@ -80,11 +80,11 @@ class ChunkCipherDecryptAttributes(object):
         self.keydataOut = None
         ##(string) The data chunk cipher ID that the data was decrypted with
         self.cipheridOut = None
-        ##(agent::KeyAttributesDict) The key attributes that are associated with the key used to decrypt the data
+        ##(\link ionicsdk.common.KeyAttributesDict KeyAttributesDict \endlink) The key attributes that are associated with the key used to decrypt the data
         self.attributesOut = None
-        ##(agent::KeyAttributesDict) The mutable key attributes that are associated with the key used to decrypt the data
+        ##(\link ionicsdk.common.KeyAttributesDict KeyAttributesDict \endlink) The mutable key attributes that are associated with the key used to decrypt the data
         self.mutableAttributesOut = None
-        ##(agent::MetadataDict) The metadata properties to send along with the HTTP request
+        ##(\link ionicsdk.common.MetadataDict MetadataDict \endlink) The metadata properties to send along with the HTTP request
         self.metadata = metadata
 
 class ChunkCrypto(object):
@@ -171,10 +171,10 @@ class ChunkCipherBase(object):
         @param
             plaintext (string): The plaintext input string.
         @param
-            attributes (agent.KeyAttributesDict, optional): The
+            attributes (KeyAttributesDict, optional): The
                     attributes to use when creating a key to protect data.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (MetadataDict, optional): The metadata
                     properties to send along with the HTTP request.
         @param
             mutableAttributes (KeyAttributesDict, optional): The protection key
@@ -241,10 +241,10 @@ class ChunkCipherBase(object):
         @param
             plaintextbytes (bytes): The binary plaintext input buffer.
         @param
-            attributes (agent.KeyAttributesDict, optional): The
+            attributes (KeyAttributesDict, optional): The
                     attributes to use when creating a key to protect data.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (MetadataDict, optional): The metadata
                     properties to send along with the HTTP request.
         @param
             mutableAttributes (KeyAttributesDict, optional): The protection key
@@ -313,7 +313,7 @@ class ChunkCipherBase(object):
         @param
             ciphertext (string): The ciphertext input string.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (MetadataDict, optional): The metadata
                          properties to send along with the HTTP request.
 
         @return
@@ -376,7 +376,7 @@ class ChunkCipherBase(object):
         @param
             ciphertext (string): The ciphertext input string.
         @param
-            metadata (agent.MetadataDict, optional): The metadata
+            metadata (MetadataDict, optional): The metadata
                          properties to send along with the HTTP request.
 
         @return
