@@ -6,6 +6,7 @@ from ionicsdk.exceptions import *
 from ionicsdk.errors import *
 from ionicsdk.secretshare import *
 from collections import defaultdict
+import os, sys
 
 class KeyData(object):
     """!Defines a data protection key as returned by Ionic.com."""
@@ -722,10 +723,7 @@ class DeviceProfilePersistorDefault(DeviceProfilePersistorBase):
     """!Default device profile persistor implementation.
     
     This class provides the default device persistor implementation for
-    the environment / operating system that the program runs in.  On
-    platforms without a default persistor implementation (e.g. Linux)
-    a persistor will be created but attempting to load or save profiles
-    with it will result in an AGENT_NO_PROFILE_PERSISTOR IonicException.
+    the environment / operating system that the program runs.
     """
     def __init__(self):
         """!Constructs a persistor with default values
@@ -783,6 +781,66 @@ class DeviceProfilePersistorAesGcmFile(DeviceProfilePersistorBase):
             _private.CMarshalUtil.bytesToC(keydata),
             _private.CMarshalUtil.bytesToC(authdata))
 
+if os.name == 'posix':
+    if sys.platform == 'mac' or sys.platform == 'darwin':
+        class DeviceProfilePersistorMac(DeviceProfilePersistorBase):
+            """!Mac keychain protected device profile persistor implementation.
+            
+            This class provides a file-based device persistor that is protected
+            by an encryption key stored in the Mac keychain.
+            """
+            def __init__(self, filepath=None, keychainAccessDescription=None):
+                """!Constructs a persistor with the provided values
+
+                @param
+                    filepath (string): Optional, the file name and path
+                @param
+                    keychainAccessDescription (string): Optional, the description to show if 
+                    the OS keychain needs to prompt for permission.
+                """
+                super(DeviceProfilePersistorMac,self).__init__()
+                ##(unicode) File name and path where the encrypted JSON file will be located
+                self.filepath = filepath
+                self._cPersistor = _private.cLib.ionic_profile_persistor_create_mac(
+                    _private.CMarshalUtil.stringToC(filepath),
+                    _private.CMarshalUtil.stringToC(keychainAccessDescription))
+    else:
+        class DeviceProfilePersistorLinux(DeviceProfilePersistorBase):
+            """!Linux file permission protected device profile persistor implementation.
+            
+            This class provides a file-based device persistor that is protected
+            by Linux file permissions, but is not encrypted.
+            """
+            def __init__(self, filepath=None):
+                """!Constructs a persistor with the provided values
+
+                @param
+                    filepath (string): Optional, the file name and path
+                """
+                super(DeviceProfilePersistorLinux,self).__init__()
+                ##(unicode) File name and path where the JSON file will be located
+                self.filepath = filepath
+                self._cPersistor = _private.cLib.ionic_profile_persistor_create_linux(
+                    _private.CMarshalUtil.stringToC(filepath))
+else:
+    class DeviceProfilePersistorWindows(DeviceProfilePersistorBase):
+        """!Windows DPAPI protected device profile persistor implementation.
+        
+        This class provides a file-based device persistor that is protected
+        by an encryption using DPAPI.
+        """
+        def __init__(self, filepath=None):
+            """!Constructs a persistor with the provided values
+
+            @param
+                filepath (string): Optional, the file name and path
+            """
+            super(DeviceProfilePersistorWindows,self).__init__()
+            ##(unicode) File name and path where the encrypted JSON file will be located
+            self.filepath = filepath
+            self._cPersistor = _private.cLib.ionic_profile_persistor_create_windows(
+                _private.CMarshalUtil.stringToC(filepath))
+
 class DeviceProfilePersistorPlaintextFile(DeviceProfilePersistorBase):
     """!Plaintext device profile persistor implementation.
     
