@@ -723,7 +723,7 @@ class KeyVaultAppleKeyChain(KeyVault):
         return _private.CMarshalUtil.stringFromC(cAccountName)
 
     def GetProtectionKey(self):
-        """!Getter for the AES GCM key to use for protecting the kay vault data
+        """!Getter for the AES GCM key to use for protecting the key vault data
 
         @return
             (bytearray) The AES GCM key
@@ -732,7 +732,7 @@ class KeyVaultAppleKeyChain(KeyVault):
         return _private.CMarshalUtil.bytesFromC(cKeybytes)
 
     def GetProtectionAuthData(self):
-        """!Getter for the AES GCM Additional Authenticated Data (AAD) to use for protecting the kay vault data
+        """!Getter for the AES GCM Additional Authenticated Data (AAD) to use for protecting the key vault data
 
         @return
             (bytearray) The AES GCM Additional Authenticated Data (AAD)
@@ -823,7 +823,7 @@ class KeyVaultMac(KeyVault):
         KeyVault service object for Mac, which uses an encrypted file using the Mac key chain to store keys
 
         ServiceName - The keychain service name to use for storing the key vault protection key.
-            Defaults to "com.ionicsecurity.client.sdk.keyvault.applekeychain"
+            Defaults to "com.ionicsecurity.client.sdk.keyvault.mac"
             
         AccountName - The keychain account name to use for storing the key vault protection key.
             Defaults to "Ionic Security"
@@ -850,7 +850,7 @@ class KeyVaultMac(KeyVault):
         """!Getter for the default Apple key chain Service Name
 
         @return
-            (string) Hard coded default service name "com.ionicsecurity.client.sdk.keyvault.applekeychain"
+            (string) Hard coded default service name "com.ionicsecurity.client.sdk.keyvault.mac"
         """
         cServiceName = _private.cLib.ionic_keyvault_mac_get_default_service_name()
         return _private.CMarshalUtil.stringFromC(cServiceName)
@@ -870,7 +870,7 @@ class KeyVaultMac(KeyVault):
         """!Getter for the default filename and path used to stored the keys.
 
         @return
-            (string) Hard coded default file name plus system user path "KeyVaultMac.dat"
+            (string) System user path plus hard coded default file name "KeyVaultMac.dat"
         """
         cFilePathOut = _private.cLib.ionic_keyvault_mac_get_default_file_path()
         return _private.CMarshalUtil.stringFromC(cFilePathOut)
@@ -961,7 +961,7 @@ class KeyVaultWindowsDpApi(KeyVault):
         """!Getter for the default file path used for the key vault storage
 
         @return
-            (string) Hard coded filename plus the system user path "KeyVaultDpapi.dat"
+            (string) System application data path plus hard coded default file name "KeyVaultDpapi.dat"
         """
         cFilePathOut = _private.cLib.ionic_keyvault_windows_dpapi_get_default_file_path()
         return _private.CMarshalUtil.stringFromC(cFilePathOut)
@@ -986,4 +986,53 @@ class KeyVaultWindowsDpApi(KeyVault):
         _private.cLib.ionic_keyvault_windows_dpapi_set_file_path(self._cAgentHandle, cFilePath)
 
 
+class KeyVaultLinux(KeyVault):
+    """!KeyVault service object for Linux, which uses the Linux file permissions
+    FilePath - The file path and file name of the file to use to store the keys.
 
+    Constructor takes a file name (with path).  Key vault is stored in this file.  You may
+        use None for this argument, in which case, the key vault uses a default name in your 
+        user folder. "<UserHome>/.ionicsecurity/keyvault.dat" 
+    """
+
+    def __init__(self, filePath=None):
+        """!Initializes the key vault with an optional file path, using defaults for other properties.
+            
+        @param
+            filePath (string) The file path at which to read/write the key vault data.
+        """
+        
+        if filePath is None:
+            filePath = KeyVaultLinux.GetDefaultFilePath()
+        
+        cFilePathOut = _private.CMarshalUtil.stringToC(filePath)
+        self._cAgentHandle = _private.cLib.ionic_keyvault_create_linux_vault(cFilePathOut)
+
+    @staticmethod
+    def GetDefaultFilePath():
+        """!Getter for the default file path used for the key vault storage
+
+        @return
+            (string) System user path plus hard coded default filename "keyvault.dat"
+        """
+        cFilePathOut = _private.cLib.ionic_keyvault_linux_get_default_file_path()
+        return _private.CMarshalUtil.stringFromC(cFilePathOut)
+
+    def GetFilePath(self):
+        """!Getter for the file path used for the key vault storage, if not previously set, returns the default path
+
+        @return
+            (string) The current file path used to store the Key Vault
+        """
+        cFilePathOut = _private.cLib.ionic_keyvault_linux_get_file_path(self._cAgentHandle)
+        return _private.CMarshalUtil.stringFromC(cFilePathOut)
+
+    def SetFilePath(self, filePath):
+        """!Setter for the file path used for the key vault storage
+        @param
+            filePath (string) The filename and path used to store the Key Vault.
+        @return
+            None
+        """
+        cFilePath = _private.CMarshalUtil.stringToC(filePath)
+        _private.cLib.ionic_keyvault_linux_set_file_path(self._cAgentHandle, cFilePath)
