@@ -2,6 +2,7 @@
 """
 import ionicsdk._private as _private
 from ionicsdk.common import *
+from ionicsdk.agent import *
 from ionicsdk.exceptions import *
 from ionicsdk.errors import *
 import ionicsdk.log
@@ -13,9 +14,6 @@ class AgentKeyServicesBase(object):
         like chunk cipher and file cryto. A user may sub class this base class to create their own local key
         storage services, or the user could use \ref agent.Agent, which uses the Ionic web server to store and 
         create keys.<br><br>See also a usage example here: \ref isagentkeyservices
-
-        The interfaces createkey2 and createkeys2 are deprecated and support for them will be removed in a 
-        future version.
     """
     def hasactiveprofile(self):
         """!Determine if any device profile is active.
@@ -183,20 +181,6 @@ class AgentKeyServicesBase(object):
     #    raise Exception("Implement this method!")
     #    return 0
     
-    ### DEPRECATED
-    ## These interfaces were previously supported in 1.4 but are currently deprecated.
-    ## Implementations of them will be used if the current version interfaces are not found
-    ## Support will be removed in the future, so please migrate your application to use 
-    ## the current createkey[s] interfaces above
-    #def createkey2(self, attributesdict = None, mutableAttributesdict = None, metadatadict = None):
-    #    raise Exception("Implement this method! or CreateKey")
-    #    raise IonicServerException("Raise this error in case of HTTP errors!")
-    #    return None # key data
-    #def createkeys2(self, keycount, attributesdict = None, mutableAttributesdict = None, metadatadict = None):
-    #    raise Exception("Implement this method! or CreateKeys")
-    #    raise IonicServerException("Raise this error in case of HTTP errors!")
-    #    return None # list of key data
-
 ##(List) Internal variable that tracks 'C' marshalling instances across callbacks.
 refs = list()
 
@@ -271,14 +255,7 @@ class _ServicesInternal:
                 except TypeError: # We had the wrong arguments, try older interfaces
                     frameinfo = getframeinfo(currentframe())
                     ionicsdk.log.log(ionicsdk.log.SEV_WARN, ionicsdk.log.PYTHON_LOG_CHANNEL, frameinfo.lineno, frameinfo.filename,
-                        "Did not find a current createkeys services interface. Please update deprecated interfaces.")
-                    try: # first try the '2' interface from v1.4
-                        keydatalist = self.service.createkeys2(nCount, attributesdict=attrdict, mutableAttributesdict=mutableAttrdict, metadatadict=metadict)
-                    except AttributeError: # If there's no '2' interface, try v1.3
-                        if mutableAttrdict is not None and len(mutableAttrdict) > 0:
-                            # Mutable attributes were specified but not supported
-                            raise Exception("Mutable Attributes were specified but no key services implementation supports them.")
-                        keydatalist = self.service.createkeys(nCount, attributesdict=attrdict, metadatadict=metadict)
+                        "Did not find a current createkeys services interface.")
                 cKeys = _private.pointer((_private.CKeyData * nCount)())
                 cKeys = _private.cast(cKeys, _private.POINTER(_private.POINTER(_private.CKeyData)))
                 cKeyArray = _private.pointer(_private.CKeyDataArray(cKeys, nCount))
@@ -307,6 +284,47 @@ class _ServicesInternal:
                 self.logCallbackError(err)
                 return IonicError.AGENT_UNKNOWN
 
+        def cb_createkeys3(cContext, cCreateKeysRequest, pKeyArrayOut, pServerResponseOut):
+            try:
+                pyCreateKeysRequest =ionicsdk.CreateKeysRequest._marshalFromC(cCreateKeysRequest)
+                keydatalist = self.service.createkeys2(pyCreateKeysRequest)
+                nCount = sum([keyreq.count for keyreq in pyCreateKeysRequest.keys])
+                cKeys = _private.pointer((_private.CKeyData * nCount)())
+                cKeys = _private.cast(cKeys, _private.POINTER(_private.POINTER(_private.CKeyData)))
+                cRefs = None
+                if hasattr(pyCreateKeysRequest.keys[0],"ref"):
+                    cRefs = _private.pointer((_private.c_char_p * nCount)())
+                    cRefs = _private.cast(cRefs, _private.POINTER(c_char_p))
+                cKeyArray = _private.pointer(_private.CKeyDataArray(cKeys, nCount, cRefs))
+                i = 0
+                for key in keydatalist:
+                    cKeyArray[0].ppKeyArray[i] = _private.pointer(KeyData._marshalToC(key))
+                    if hasattr(key,"ref"):
+                        cKeyArray[0].ppszRefs[i] = _private.CMarshalUtil.stringToC(key.ref)
+                    else:
+                        cKeyArray[0].ppszRefs[i] = _private.CMarshalUtil.stringToC("")
+                    i = i + 1
+                pKeyArrayOut[0] = cKeyArray
+                # consider setting a 'good' server response here for completeness
+                # (currently there is no way in python to retrieve a 'good' response)
+                # Keep a handle to the relevant objects so they don't get free'd before the C layer finishes
+                ref = _private.cast(pKeyArrayOut[0],_private.c_void_p)
+                self.refmap[ref.value] = [keydatalist, cKeyArray, ref]
+                return IonicError.AGENT_OK
+            except IonicServerException as err:
+                if pServerResponseOut != 0:
+                    serverResponse = IonicServerException._marshalToC(err)
+                    pServerResponseOut[0] = _private.pointer(serverResponse)
+                    ref = _private.cast(pServerResponseOut[0],_private.c_void_p)
+                    self.refmap[ref.value] = [serverResponse, pServerResponseOut[0], ref]
+                    return err.code
+                return IonicError.AGENT_UNEXPECTEDRESPONSE
+            except IonicException as err:
+                return err.code
+            except Exception as err:
+                self.logCallbackError(err)
+                return IonicError.AGENT_UNKNOWN
+
         def cb_getkey(cContext, sKeyId, cMetaMap, pKeyDataOut, pServerResponseOut):
             try:
                 metadict = MetadataDict._marshalFromC(cMetaMap)
@@ -337,8 +355,10 @@ class _ServicesInternal:
         def cb_getkeys(cContext, sKeyIdArray, nCount, cMetaMap, pKeyArrayOut, pServerResponseOut):
             try:
                 metadict = MetadataDict._marshalFromC(cMetaMap)
-                keydatalist = self.service.getkeys(cSize, sKeyIdArray, metadict)
+                pyKeyIds = _private.CMarshalUtil.stringArrayFromC(sKeyIdArray, nCount)
+                keydatalist = self.service.getkeys(pyKeyIds, metadict)
                 cKeys = _private.pointer((_private.CKeyData * nCount)())
+                cKeys = _private.cast(cKeys, _private.POINTER(_private.POINTER(_private.CKeyData)))
                 cKeyArray = _private.pointer(_private.CKeyDataArray(cKeys, nCount))
                 i = 0
                 for key in keydatalist:
@@ -397,6 +417,7 @@ class _ServicesInternal:
                 updateKeyDataListIn = UpdateKeyDataList._marshalFromC(cUpdateKeyDataArrayIn)
                 keyDataListOut = self.service.updatekeys(updateKeyDataListIn, metadict)
                 cKeys = _private.pointer((_private.CKeyData * nCount)())
+                cKeys = _private.cast(cKeys, _private.POINTER(_private.POINTER(_private.CKeyData)))
                 cKeyArray = _private.pointer(_private.CKeyDataArray(cKeys, nCount))
                 i = 0
                 for key in keyDataListOut:
@@ -489,6 +510,8 @@ class _ServicesInternal:
         cServStruct.pfGetActiveProfile      = _private.ServicesCallback_get_active_profile(cb_getactiveprofile)
         cServStruct.pfCreateKey2            = _private.ServicesCallback_create_key2(cb_createkey)
         cServStruct.pfCreateKeys2           = _private.ServicesCallback_create_keys2(cb_createkeys)
+        if 'createkeys2' in dir(self.service):
+            cServStruct.pfCreateKeys3       = _private.ServicesCallback_create_keys3(cb_createkeys3)
         cServStruct.pfGetKey                = _private.ServicesCallback_get_key(cb_getkey)
         cServStruct.pfGetKeys               = _private.ServicesCallback_get_keys(cb_getkeys)
         cServStruct.pfReleaseKeyData        = _private.ServicesCallback_release_key_data(cb_releasekeydata)
